@@ -1241,6 +1241,10 @@ class SECoPCP(Runner):
         parser.add_argument("-a", "--can-fail", action="store_true",
                             default=False, dest="canfail",
                             help="can fail strategy flag")
+        parser.add_argument("-q", "--strict", action="store_true",
+                            default=False, dest="strict",
+                            help="NeXus strict group types i.e. "
+                            "use NXcollection if not defined")
         parser.add_argument("-c", "--component",
                             help="component name" +
                             "secop component name",
@@ -1262,6 +1266,35 @@ class SECoPCP(Runner):
         parser.add_argument("-s", "--sample",
                             help="sample name",
                             dest="samplename", default="")
+
+        parser.add_argument("-k", "--links",
+                            help="NXlog links of physical "
+                            "quantities to sensors "
+                            "separated by comman. Default: "
+                            "'temperature,magnetic_field,"
+                            "electric_field,"
+                            "stress_field,pressure'",
+                            dest="meanings",
+                            default="temperature,magnetic_field,"
+                            "electric_field,"
+                            "stress_field,pressure")
+        parser.add_argument("-v", "--environments",
+                            help="NXenvironment links of physical quantities "
+                            "separated by comman. "
+                            "Default: 'temperature,magnetic_field'",
+                            dest="environments",
+                            default="temperature,magnetic_field")
+        parser.add_argument("-f", "--first",
+                            help="first linked targets separated by comman",
+                            dest="first", default="")
+        parser.add_argument(
+            "-z", "--transformation-attributes", dest="transattrs",
+            default='{"rotation_z":'
+            '{"transformation_type":"rotation","vector":[0,-1,0]}}',
+            help=("a JSON dictionary with transformation parameters i.e, "
+                  '"transformation_type", "vector", "depends_on".'
+                  ' Default: {"rotation_z":'
+                  '{"transformation_type":"rotation","vector":[0,-1,0]}}'))
         parser.add_argument("-p", "--xml-package", dest="xmlpackage",
                             help="xml template package")
         parser.add_argument("-y", "--entryname", dest="entryname",
