@@ -24,6 +24,9 @@ import json
 import sys
 import xml.etree.ElementTree as et
 import numpy as np
+import pytz
+import time
+import dateutil.parser
 from lxml.etree import XMLParser
 
 from nxstools.nxsparser import ParserTools
@@ -200,6 +203,8 @@ class NXSFileParser(object):
         self.filters = []
         # (:obj:`bool`) oned value flag
         self.oned = False
+        # (:obj:`int`) maximal 1d record size
+        self.maxonedsize = -1
 
     @classmethod
     def getpath(cls, path):
@@ -457,7 +462,8 @@ class NXSFileParser(object):
             if (node.name in self.valuestostore and node.is_valid) \
                or "shape" not in desc \
                or desc["shape"] in [None, [1], []] \
-               or (self.oned and len(desc["shape"]) == 1):
+               or ((self.oned)
+                   and len(desc["shape"]) == 1):
                 if hasattr(node, "read"):
                     try:
                         vl = node.read()
@@ -476,7 +482,12 @@ class NXSFileParser(object):
                                     cont = False
                             except Exception:
                                 cont = False
-                        nd["value"] = vl
+                        if self.maxonedsize >= 0 and len(desc["shape"]) == 1 \
+                           and hasattr(vl, "__len__") and \
+                           len(vl) > self.maxonedsize:
+                            nd["value"] = [vl[0], vl[-1]]
+                        else:
+                            nd["value"] = vl
                         if self.emptyunits and "unit" not in nd.keys():
                             nd["unit"] = ""
                     except Exception:
@@ -558,6 +569,8 @@ class FIOFileParser(object):
         self.__root = root
         # (:obj:`bool`) oned value flag
         self.oned = False
+        # (:obj:`int`) maximal 1d record size
+        self.maxonedsize = -1
 
     def _appendComments(self, lines, meta):
         """append comments
@@ -579,19 +592,44 @@ class FIOFileParser(object):
                 sline = line.split("Acquisition started at ")
                 if sline and sline[-1].strip():
                     meta["start_time"] = {
-                        "value": sline[-1].strip(),
+                        "value": self._isoDate(sline[-1].strip()),
                         "unit": ""
                     }
             elif "Acquisition ended at " in line:
                 sline = line.split("Acquisition ended at ")
                 if sline and sline[-1].strip():
                     meta["end_time"] = {
-                        "value": sline[-1].strip(),
+                        "value": self._isoDate(sline[-1].strip()),
                         "unit": ""
                     }
         if comments:
             meta["comments"] = comments
 
+    @classmethod
+    def _isoDate(cls, text):
+        """ convert date to iso format
+
+        :param text: date text to convert
+        :type text: :obj:`str`
+        :returns: date in iso format
+        :rtype: :obj:`str`
+        """
+        try:
+            date = dateutil.parser.parse(text)
+            if date.tzinfo is None:
+                tzone = time.tzname[0]
+                try:
+                    tz = pytz.timezone(tzone)
+                except Exception:
+                    import tzlocal
+                    tz = tzlocal.get_localzone()
+                date = tz.localize(date)
+            fmt = '%Y-%m-%dT%H:%M:%S.%f%z'
+            result = str(date.strftime(fmt))
+        except Exception:
+            result = text
+        return result
+
     def _appendParameters(self, lines, meta):
         """append comments
 
@@ -649,8 +687,12 @@ class FIOFileParser(object):
                         except Exception:
                             self.columns[wid][1].append(str(word))
         for wid, nmvl in self.columns.items():
-            data[nmvl[0]] = nmvl[1]
-
+            if self.maxonedsize >= 0 \
+               and hasattr(nmvl[1], "__len__") and \
+               len(nmvl[1]) > self.maxonedsize:
+                data[nmvl[0]] = [nmvl[1][0], nmvl[1][-1]]
+            else:
+                data[nmvl[0]] = nmvl[1]
         if data:
             meta["data"] = data
 
@@ -678,5 +720,5 @@ class FIOFileParser(object):
                 self._appendComments(dcpmap["%c"], nd)
             if dcpmap["%p"]:
                 self._appendParameters(dcpmap["%p"], nd)
-            if dcpmap["%d"] and self.oned:
+            if dcpmap["%d"] and (self.oned):
                 self._appendData(dcpmap["%d"], nd)
