@@ -194,6 +194,8 @@ if PYTANGO_AVAILABLE:
     import NXSCreatePoolDSFS2_test
     import NXSCreatePoolDSFS3_test
 
+    import NXSCreateSECoPCPFS_test
+
     import NXSData_test
 
     if "MYSQL" in DB_AVAILABLE:
@@ -249,6 +251,8 @@ if PYTANGO_AVAILABLE:
         import NXSCreatePoolDSDBR_test
         import NXSCreatePoolDSDBR2_test
 
+        import NXSCreateSECoPCPDB_test
+
 
 # main function
 def main():
@@ -361,6 +365,10 @@ def main():
             unittest.defaultTestLoader.loadTestsFromModule(
                 NXSCreatePoolDSFS3_test))
 
+        suite.addTests(
+            unittest.defaultTestLoader.loadTestsFromModule(
+                NXSCreateSECoPCPFS_test))
+
         suite.addTests(
             unittest.defaultTestLoader.loadTestsFromModule(
                 NXSCreateDeviceDSFS_test))
@@ -451,6 +459,10 @@ def main():
                 unittest.defaultTestLoader.loadTestsFromModule(
                     NXSCreateOnlineDSDBR2_test))
 
+            suite.addTests(
+                unittest.defaultTestLoader.loadTestsFromModule(
+                    NXSCreateSECoPCPDB_test))
+
             suite.addTests(
                 unittest.defaultTestLoader.loadTestsFromModule(
                     NXSCreateOnlineDSDBE_test))
